﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using Infragistics.WebUI.Shared;

namespace ScheduleMountain
{
    public partial class _Default : Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            object objMap = Session["WebScheduleObjects"] as object[];
            this.dataMap = objMap as Dictionary<string, object>;

            if (IsPostBack && this.dataMap != null)
            {
                this.MyResources = (IList)this.dataMap["Resources"];
                this.MyFixtures = this.dataMap["Appointments"] as ICollection; // List<Fixtures>;
            }
            else
            {
                this.MyResources = GetResources();
                IList fixxies = GenerateFixtures();
                this.MyFixtures = fixxies;

                this.dataMap = new Dictionary<string, object>();
                this.dataMap.Add("Appointments", this.MyFixtures);
                this.dataMap.Add("Resources", this.MyResources);

                Session["WebScheduleObjects"] = this.dataMap;

                this.wsInfo.ActiveDayUtc = this.wsInfo.ConvertTimeZoneTimeToUtc(new Infragistics.WebUI.Shared.SmartDate(((Fixtures)fixxies[0]).GameDate.ToString()));
            }

            WebScheduleGenericProviderBindings();

            this.WebScheduleGenericDataProvider1.ActivityDataSource = this.MyFixtures;
            this.WebScheduleGenericDataProvider1.VarianceDataSource = this.MyFixtures;

            this.WebScheduleGenericDataProvider1.ResourceDataSource = this.MyResources;
        }


        public IList GenerateFixtures() //public List<Fixtures> GenerateFixtures()
        {
            DateTime firstDay = new DateTime(2014, 8, 20, 13, 30, 0);
            DateTime lastDay = new DateTime(2015, 5, 20, 13, 30, 0);
            TimeSpan seasonSpan = lastDay.Subtract(firstDay);

            Random r = new Random();
            int hTeam;
            int vTeam;
            List<Fixtures> season = new List<Fixtures>();
            Fixtures f;
            for (int a = 1; a <= 4; ++a)
            {
                hTeam = r.Next(0, 19);
                vTeam = r.Next(0, 19);
                while (hTeam == vTeam)
                {
                    vTeam = r.Next(0, 19);
                }

                f = new Fixtures(this.wsInfo);
                f.GameDuration = 145 * 60;
                f.HomeTeam = Fixtures.Teams[hTeam];
                f.Visitors = Fixtures.Teams[vTeam];
                f.GameDate = GetGameDate(firstDay, seasonSpan);
                f.AllDayEvent = false;
                f.Status = 1;
                f.EnableReminders = false;
                f.ShowTimeAs = 1;
                f.Importance = 1;
                f.VarianceID = Guid.NewGuid().ToString();
                f.RecurrencePattern = null;
                f.RecurrenceID = -1;
                f.OriginalStartDateTimeUtc = null;

                int resKey = r.Next(0, 2);
                f.ResourceKey = "1";
                f.TYPEICONPATH = "Labradoodle";

                season.Add(f);
            }
            return season;
        }


        private TimeSpan seasonSpan;

        private DateTime GetGameDate(DateTime firstDay, TimeSpan seasonSpan)
        {
            Random r = new Random();
            int dayPick = r.Next(0, seasonSpan.Days - 1);
            DateTime gameDate = firstDay.AddDays(dayPick);

            return gameDate;
        }


        private IList GetResources()
        {
            List<MyResources> resources = new List<MyResources>();

            resources.Add(new MyResources(1, "Alan Pardew", "Alan Pardew", "apardew@crystalpalace.com"));
//            resources.Add(new MyResources(2, "Arsene Wenger", "Arsene Wenger", "awenger@arsenal.com"));
//            resources.Add(new MyResources(3, "José  Mourinho", "José  Mourinho", "jmourinho@chelseafc.com"));

            return resources;
        }

        protected void WebScheduleGenericProviderBindings()
        {
            this.WebScheduleGenericDataProvider1.AppointmentBinding.DescriptionMember = "Description";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.DataKeyMember = "ID";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.DurationMember = "Duration";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.EnableReminderMember = "EnableReminders";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.LocationMember = "Location";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.OriginalStartDateTimeUtcMember = "OriginalStartDateTimeUtc";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.RecurrenceKeyMember = "RecurrenceID";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.ResourceKeyMember = "ResourceKey";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.AllDayEventMember = "AllDayEvent";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.RecurrencePatternMember = "RecurrencePattern";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.ShowTimeAsMember = "ShowTimeAs";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.StartDateTimeUtcMember = "StartDateTimeUtc";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.StatusMember = "Status";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.SubjectMember = "Subject";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.VarianceKeyMember = "VarianceID";
            this.WebScheduleGenericDataProvider1.AppointmentBinding.ImportanceMember = "Importance";

            this.WebScheduleGenericDataProvider1.VarianceBinding.DescriptionMember = "Description";
            this.WebScheduleGenericDataProvider1.VarianceBinding.DataKeyMember = "ID";
            this.WebScheduleGenericDataProvider1.VarianceBinding.DurationMember = "Duration";
            this.WebScheduleGenericDataProvider1.VarianceBinding.EnableReminderMember = "EnableReminders";
            this.WebScheduleGenericDataProvider1.VarianceBinding.LocationMember = "Location";
            this.WebScheduleGenericDataProvider1.VarianceBinding.OriginalStartDateTimeUtcMember = "OriginalStartDateTimeUtc";
            this.WebScheduleGenericDataProvider1.VarianceBinding.RecurrenceKeyMember = "RecurrenceID";
            this.WebScheduleGenericDataProvider1.VarianceBinding.ResourceKeyMember = "ResourceKey";
            this.WebScheduleGenericDataProvider1.VarianceBinding.AllDayEventMember = "AllDayEvent";
            this.WebScheduleGenericDataProvider1.VarianceBinding.RecurrencePatternMember = "RecurrencePattern";
            this.WebScheduleGenericDataProvider1.VarianceBinding.ShowTimeAsMember = "ShowTimeAs";
            this.WebScheduleGenericDataProvider1.VarianceBinding.StartDateTimeUtcMember = "StartDateTimeUtc";
            this.WebScheduleGenericDataProvider1.VarianceBinding.StatusMember = "Status";
            this.WebScheduleGenericDataProvider1.VarianceBinding.SubjectMember = "Subject";
            this.WebScheduleGenericDataProvider1.VarianceBinding.VarianceKeyMember = "VarianceID";
            this.WebScheduleGenericDataProvider1.VarianceBinding.ImportanceMember = "Importance";

            this.WebScheduleGenericDataProvider1.ResourceBinding.DataKeyMember = "ID";
            this.WebScheduleGenericDataProvider1.ResourceBinding.NameMember = "ResourceName";
            this.WebScheduleGenericDataProvider1.ResourceBinding.DescriptionMember = "ResourceDescription";
            this.WebScheduleGenericDataProvider1.ResourceBinding.EmailAddressMember = "EmailAddress";
        }

        public ICollection MyFixtures;
        public IList MyResources;
        public Dictionary<string, object> dataMap;
        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);
        }
    }
}